'use strict';

const isWsl = require('is-wsl');
const shell = require('shelljs');
const semver = require('semver');
const fs = require('fs');
const path = require('path');
const npm = 'npm'; //require('./npm')

function getPlatform() {
  return isWsl ? 'wsl' : process.platform;
}

const supportedPlatforms = ['darwin', 'linux', 'win32', 'wsl'];
function getChromePath() {
  return new Promise((resolve, reject) => {
    const pf = getPlatform();
    const errorMsg = 'No Chrome Installations Found';
    if (supportedPlatforms.indexOf(pf) < 0) return reject(); // throw new Error(errorMsg)
    resolve(undefined, errorMsg);
  });
}

exports.getPlatform = getPlatform;
exports.getChromePath = getChromePath;

// install puppeteer
function install(chromePath) {
  const installPuppeteer = npm + ' install puppeteer --registry=https://registry.npm.taobao.org';
  let preCommand;
  let cmd;

  if (chromePath) {
    preCommand = 'PUPPETEER_SKIP_CHROMIUM_DOWNLOAD=true';
  } else {
    preCommand = 'PUPPETEER_DOWNLOAD_HOST=https://npm.taobao.org/mirrors';
  }

  if (getPlatform() === 'win32') {
    cmd = 'set ' + preCommand + '&&' + installPuppeteer;
  } else {
    cmd = preCommand + ' ' + installPuppeteer;
  }

  shell.exec(cmd, { silent: true });
}

if (!fs.existsSync(path.resolve(__dirname, '../node_modules/puppeteer'))) {
  getChromePath().then(install).catch(install);
}
